Module: Arduino::Library::Finder
- Extended by:
- FinderMethods, InstanceMethods
- Defined in:
- lib/arduino/library/finder.rb
Overview
The goal of this class is to identify a single library complete with all the metadata, in particular URL, so that the library can be installed.
We accept partial information about the library, and construct query based this information. If multiple entries returned, but for the same library, the latest version is returned.
Defined Under Namespace
Modules: FinderMethods